@@ -10,8 +10,8 @@ from collections import namedtuple
 from enum import Enum
 from typing import List
 
-version = '3.1.18'
-version_info = list(map(int, version.split('.')))
+version = "3.1.18"
+version_info = list(map(int, version.split(".")))
 
 
 class Component(Enum):
@@ -33,9 +33,10 @@ class Component(Enum):
     Sanic = 7007
     AioHttp = 7008
     Pyramid = 7009
+    RQ = 42
 
 
-class ComponentType():
+class ComponentType:
     Unknown = "Unknown"
     General = "General"  # built-in modules that may not have a logo to display
     Flask = "Flask"
@@ -59,6 +60,7 @@ class ComponentType():
     Pyramid = "Pyramid"
     CustomEvent = "CustomEvent"
     Log = "Log"
+    RQ = "RQ"
 
 
 class Layer(Enum):
