@@ -62,14 +62,14 @@ def __fini():
 
 
 def start():
-    functions.log("Config.Enable is %s ", config.enable)
+    functions.log("Config.Enable is %r ", config.enable)
     # 如果探针开关关闭,则不执行探针的初始化操作，不启动探针
     if not config.enable:
         return False
 
-    # if not config.product_code or not config.app_code:
-    #     functions.log("缺少product_code或app_code字段值，探针初始化失败")
-    #     return False
+    if not config.product_code or not config.app_code:
+        functions.log("缺少product_code或app_code字段值，探针初始化失败")
+        return False
 
     flag = False
     try:
@@ -103,10 +103,11 @@ def start():
     atexit.register(__fini)
     # 打印配置
     functions.log(
-        "探针enable配置为：%r,  logging_level配置为：%r， logging_filepath配置为：%r",
+        "探针enable配置为：%r, debug配置为：%r， logging_level配置为：%r， debug_level配置为：%r",
         config.enable,
-        config.tracker_logging.get("Level"),
-        config.tracker_logging.get("FilePath"),
+        config.debug,
+        config.logging_level,
+        config.debug_level,
     )
 
 
