@@ -8,6 +8,7 @@ from queue import Queue, Empty
 
 from fast_tracker.agent import Protocol
 from fast_tracker.client.udp import UdpTraceSegmentReportService
+from fast_tracker.trace.segment import Segment
 
 
 class UdpProtocol(Protocol):
@@ -22,7 +23,7 @@ class UdpProtocol(Protocol):
         def generator():
             while True:
                 try:
-                    segment = queue.get(block=block)
+                    segment = queue.get(block=block)  # type: Segment
                 except Empty:
                     return
 
