@@ -4,8 +4,8 @@
 """
     created by FAST-DEV 2021/4/6
 """
-import json
 import os
+import json
 import socket
 from fast_tracker import config
 from fast_tracker.fast_tracker import FastTracker
@@ -16,14 +16,13 @@ from fast_tracker.utils import functions
 DEFAULT_UDP_IP = "127.0.0.1"
 DEFAULT_UDP_PORT = 5140
 
-
 class UdpTraceSegmentReportService(TraceSegmentReportService):
     def __init__(self):
         self.udp_ip = DEFAULT_UDP_IP
         self.udp_port = DEFAULT_UDP_PORT
         if config.collector_address:
             self._init_ip_and_port(config.collector_address)
-        self.buffer_size = config.transport.get("BatchSize")
+        self.buffer_size = config.buffer_size
         self.type_dict = {"Entry": 0, "Exit": 1, "Local": 2}
         self.layer_dict = {
             "local": 0,
@@ -67,14 +66,14 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             functions.log("udp socket object success")
             for segment in generator:
                 for span in segment.spans:
-                    # functions.log("udp socket object will get data", level=4)
+                    functions.log("udp socket object will get data", level=4)
                     data = self._get_data(segment, span)
                     functions.log("udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
-                    # functions.log("udp socket object get data", level=4)
+                    functions.log("udp socket object get data", level=4)
                     res = udp_sock.sendto(data, (self.udp_ip, self.udp_port))
-                    # res = udp_sock.sendto(data, ("fast-collector", self.udp_port))
-                    # functions.log("sended udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
-                    functions.log(": %r, result is: %r", data, res)
+                    # res = udp_sock.sendto(data, ("fluent-bit", 5140))
+                    functions.log("sended udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
+                    functions.log("sended message: %r, result is: %r", data, res)
                 # segment上报完清除用户自定义字段值，避免污染之后的上报
                 config.custom_env_code = ""
                 config.custom_tenant_code = ""
@@ -82,7 +81,6 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         except BaseException as e:
             functions.log("udp report error: %r", e)
 
-
     def _get_data(self, segment, span):
         """
         udp 数据包组装
@@ -92,16 +90,16 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         """
         ft = FastTracker()
         report_struct = ReportStruct()
-        # report_struct.product_code = config.product_code
-        # report_struct.app_code = config.app_code
+        report_struct.product_code = config.product_code
+        report_struct.app_code = config.app_code
         report_struct.service_name = config.service_name
-        # report_struct.env_code = ft.env_code
+        report_struct.service_instance = "%s|%s|%s" % (config.service_name, os.getpid(), socket.gethostname())
+        report_struct.env_code = ft.env_code
         report_struct.tenant_code = ft.tenant_code
         report_struct.user_code = ft.user_code
         report_struct.trace_id = str(segment.related_traces[0])
         report_struct.parent_span_id = span.pid
         report_struct.span_id = span.sid
-        report_struct.peer = span.peer
         report_struct.span_type = self.type_dict.get(span.kind.name, 3)
         report_struct.span_layer = self.layer_dict.get(str(span.layer.name).lower(), 10)
         report_struct.start_time = span.start_time
@@ -109,14 +107,13 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         report_struct.duration = 1 if span.end_time - span.start_time == 0 else span.end_time - span.start_time
         report_struct.component = span.component
         report_struct.operation_name = span.op
+        report_struct.peer = span.peer
         report_struct.is_error = span.error_occurred
         report_struct.tags = self.convert_tags(span.tags)
         report_struct.logs = self.convert_logs(span.logs)
-        report_struct.service_instance = config.service_name + "|" + str(os.getpid())+"|"+socket.gethostname()
-        report_struct.service_version = config.get_service_version()
         report_struct.tracker_version = config.tracker_version
         item = ReportStruct.convert(report_struct)
-        #functions.log("report_struct: %r", item, level=2)
+        functions.log("report_struct: %r", item, level=2)
         data = json.dumps(item).encode("utf-8")
         return data
 
@@ -147,7 +144,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             for item in log.items:
                 if type(item.val) == str:
                     alpha = {
-                        "Timestamp": int(log.timestamp * 1000),
+                        "Timestamp": str(log.timestamp * 1000),
                         "Data": {
                             "event": item.key,
                             "message": item.val,
@@ -162,7 +159,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
                     if item.val.get("err_trace"):
                         temp["stack"] = item.val.get("err_trace")
                     alpha = {
-                        "Timestamp": int(log.timestamp * 1000),
+                        "Timestamp": str(log.timestamp * 1000),
                         "Data": temp,
                     }
                 data.append(alpha)
